==> nan_photo_selector-0.0.3.tar.gz: lib/NanShowModalBottomSheetUtils.dart <==

import 'package:flutter/material.dart';
import 'package:nan_photo_selector/NanCommonConst.dart';
import 'package:nan_photo_selector/NanCommonWidget.dart';
import 'package:nan_photo_selector/nanDialogWidget.dart';

class NanShowModalBottomSheetUtils{

  static void photoAll(BuildContext context,{List? choiceList,Function? selectResult}){//相机与相册
    showModalBottomSheet(context: context, builder: (BuildContext context){
      return SizedBox(
        height: 200,
        child: ListView.builder(itemCount: choiceList!.length,itemBuilder: (context, index){
          Map map = choiceList[index];
          return ListTile(
            leading: new Icon(index==0?Icons.photo_camera:Icons.photo),
            title: new Text(map["name"]),
            onTap: (){
              Navigator.of(context).pop();
              selectResult!(index);
            },
          );
        }),
      );
    });
  }

  static void showUploadDialog(BuildContext context,{String? upload,bool isDismiss=false,double radius=8,String tipMsg="提示文字",GestureTapCallback? onTap}){
    showDialog(context: context,barrierDismissible: isDismiss,builder: (context) {
      return BaseDialog(
        Column(
          children: <Widget>[
            SizedBox(height: 20,),
            LoadingWidget(),
            InkWell(
              child: Padding(
                padding: EdgeInsets.only(top: 20),
                child: Text(tipMsg),
              ),
              onTap: onTap,
            )
          ],
        ), 
        150, 
        kScreenWidth - 46*2, 
        radius
      );
    },);
  }
}

==> nan_photo_selector-0.0.8.tar.gz: lib/NanShowModalBottomSheetUtils.dart <==

import 'package:flutter/material.dart';
import 'package:nan_photo_selector/NanCommonConst.dart';
import 'package:nan_photo_selector/NanCommonWidget.dart';
import 'package:nan_photo_selector/nanDialogWidget.dart';

class NanShowModalBottomSheetUtils{

  static void photoAll(BuildContext context,{List choiceList,Function selectResult}){//相机与相册
    showModalBottomSheet(context: context, builder: (BuildContext context){
      return SizedBox(
        height: 200,
        child: ListView.builder(itemCount: choiceList.length,itemBuilder: (context, index){
          Map map = choiceList[index];
          return ListTile(
            leading: new Icon(index==0?Icons.photo_camera:Icons.photo),
            title: new Text(map["name"]),
            onTap: (){
              Navigator.of(context).pop();
              selectResult(index);
            },
          );
        }),
      );
    });
  }

  static void showUploadDialog(BuildContext context,{String upload,bool isDismiss=false,double radius=8,String tipMsg="提示文字",GestureTapCallback onTap}){
    showDialog(context: context,barrierDismissible: isDismiss,builder: (context) {
      return BaseDialog(
        Column(
          children: <Widget>[
            SizedBox(height: 20,),
            LoadingWidget(),
            InkWell(
              child: Padding(
                padding: EdgeInsets.only(top: 20),
                child: Text(tipMsg),
              ),
              onTap: onTap,
            )
          ],
        ), 
        150, 
        kScreenWidth - 46*2, 
        radius
      );
    },);
  }
}
